@@ -59,7 +59,7 @@ class AbstractBuffer:
             await self.__process_buffer()
 
     async def add_to_buffer(self, value: Any) -> None:
-        if len(self._buffer) >= self._config.MAX_VALUES_IN_BUFFER - 1:
+        if len(self._buffer) >= self._config.MAX_VALUES_IN_BUFFER:
             await self._buffer_flushed_event.wait()
         self._buffer.append(value)
         self._new_value_event_event.set()
